@@ -13,9 +13,9 @@
 #    under the License.
 
 import os
+from unittest import mock
 
 from keystoneauth1 import loading as ks_loading
-import mock
 from oslo_config import cfg
 from oslo_config import fixture as config_fixture
 from oslo_middleware import request_id
@@ -51,8 +51,8 @@ class TestRequestContext(common.HeatTestCase):
                     'aws_creds': 'blah',
                     'region_name': 'RegionOne',
                     'user_identity': 'fooUser 456tenant',
-                    'user_domain': None,
-                    'project_domain': None}
+                    'user_domain_id': None,
+                    'project_domain_id': None}
 
         super(TestRequestContext, self).setUp()
 
@@ -73,8 +73,8 @@ class TestRequestContext(common.HeatTestCase):
             trustor_user_id=self.ctx.get('trustor_user_id'),
             trust_id=self.ctx.get('trust_id'),
             region_name=self.ctx.get('region_name'),
-            user_domain_id=self.ctx.get('user_domain'),
-            project_domain_id=self.ctx.get('project_domain'))
+            user_domain_id=self.ctx.get('user_domain_id'),
+            project_domain_id=self.ctx.get('project_domain_id'))
         ctx_dict = ctx.to_dict()
         del ctx_dict['request_id']
         del ctx_dict['project_id']
@@ -103,8 +103,8 @@ class TestRequestContext(common.HeatTestCase):
                       'aws_creds': 'blah',
                       'region_name': 'RegionOne',
                       'user_identity': u'Gāo 456tenant',
-                      'user_domain': None,
-                      'project_domain': None}
+                      'user_domain_id': None,
+                      'project_domain_id': None}
 
         ctx = context.RequestContext(
             auth_token=ctx_origin.get('auth_token'),
@@ -122,8 +122,8 @@ class TestRequestContext(common.HeatTestCase):
             trustor_user_id=ctx_origin.get('trustor_user_id'),
             trust_id=ctx_origin.get('trust_id'),
             region_name=ctx_origin.get('region_name'),
-            user_domain_id=ctx_origin.get('user_domain'),
-            project_domain_id=ctx_origin.get('project_domain'))
+            user_domain_id=ctx_origin.get('user_domain_id'),
+            project_domain_id=ctx_origin.get('project_domain_id'))
         ctx_dict = ctx.to_dict()
         del(ctx_dict['request_id'])
         self.assertEqual(ctx_origin, ctx_dict)
@@ -391,7 +391,7 @@ class RequestContextMiddlewareTest(common.HeatTestCase):
     )]
 
     def setUp(self):
-        super(RequestContextMiddlewareTest, self).setUp()
+        super(RequestContextMiddlewareTest, self).setUp(mock_find_file=False)
         self.fixture = self.useFixture(config_fixture.Config())
         self.fixture.conf(args=['--config-dir', policy_path])
         policy_opts.set_defaults(cfg.CONF, 'check_admin.json')
